/*
 * SPDX-FileCopyrightText: 2014 Martin Klapetek <mklapetek@kde.org>
 *
 * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 *
 */

#include "kaccountsdplugin.h"

KAccountsDPlugin::KAccountsDPlugin(QObject *parent, const QVariantList & /*args*/)
    : QObject(parent)
{
}

KAccountsDPlugin::~KAccountsDPlugin()
{
}
